/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * A server to accept incoming TCP socket tunnel connections.
 *
 * $Id: TCPSockTunServer.hh,v 1.1 2008-05-15 14:29:52 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _TCP_SOCK_TUN_SERVER_HH_
#define _TCP_SOCK_TUN_SERVER_HH_

#include "SockTunServer.hh"
#include "ThreadManager.hh"
#include "Mutex.hh"
#include "ConditionVar.hh"

namespace HTTPTunnel {

class TCPSockTunServer : public SockTunServer {
public:
	// Construction/destruction
	TCPSockTunServer(const SockTunCallback* userCallback) throw(TunnelError);
	virtual ~TCPSockTunServer();

protected:

private:

	/*************/
	/* Constants */
	/*************/

	// Timeout (in miliseconds) to wait in poll()
	static const int				POLL_TIMEOUT		= 100;


	/***********/
	/* Methods */
	/***********/

	// Wait for arriving connections - Thread entry point
	void startServer(void);


	/********/
	/* Data */
	/********/

	// Our main thread
	Thread*									m_thread;

	// CondVar to control sleeping
	ConditionVar							m_sleepCond;

	// Mutex/CondVar & flag to control shutdown
	Mutex										m_shutdownMtx;
	ConditionVar							m_shutdownCond;
	bool										m_shutDown;

	// A thread manager + Mutex
	ThreadManager							m_threadMgr;

};


}	// namespace

#endif

