/* (C) 2008 Richard Mills / The Linux Academy Ltd.
 *
 * A server to accept incoming UDP socket tunnel connections.
 *
 * $Id: UDPSockTunServer.cc,v 1.1 2008-05-15 14:29:52 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "UDPSockTunServer.hh"
#include "Debug.hh"
#include "Logger.hh"
#include "MutexVar.hh"
#include "UDPSock.hh"


namespace HTTPTunnel {


// Global references
extern Logger* g_pLogger;


// Construction/destruction
UDPSockTunServer::UDPSockTunServer(const SockTunCallback* userCallback) throw(TunnelError)
: SockTunServer(userCallback)
{
	DPRINTV("UDPSockTunServer::UDPSockTunServer()");

	// Create UDP socket
	m_prot = Enums::UDP;
	m_sock = new UDPSock();

	// Bind to ephemeral port on the loopback interface
	m_sock->bind(m_listenIP, m_listenPort);

	#ifdef DEBUG_TUN
	std::stringstream dbg;
	dbg << "UDPSockTunServer bound to " << m_listenIP << ":" << m_listenPort;
	DPRINTV(dbg.str());
	#endif

	// Pass UDP socket back to user
}

UDPSockTunServer::~UDPSockTunServer()
{
	DPRINTV("UDPSockTunServer::~UDPSockTunServer()");
}


}	// namespace

